@@ -10,7 +10,7 @@ _counter = defaultdict(int)
 _cum_counter = defaultdict(int)
 _outfile = None
 
-__version__ = '0.0.2'
+__version__ = '0.0.3'
 
 def _sig_handler(signal, frame):
     global _counter, _cum_counter
@@ -59,13 +59,16 @@ def install(target='cpu', interval=0.01):
 
 
 def _print_profile(counter, total, file):
-    items = counter.items()
+    items = list(counter.items())
     items.sort(key=lambda x: x[1], reverse=True)
+    basename = os.path.basename
     for code_line, count in items:
         code, lineno = code_line
-        print >>file, "%20s:%-4d %20s %f" % (
-                code.co_filename, lineno,
+        file.write(
+                "%20s:%-4d %20s %f\n" % (
+                basename(code.co_filename), lineno,
                 code.co_name, 100.0*count/total)
+                )
 
 def _show_profile():
     if _outfile is None:
@@ -74,13 +77,16 @@ def _show_profile():
         file = open(_outfile, 'w')
     if file is None:
         file = sys.stderr
-    total = sum(_counter.itervalues())
-    print >>file, "== time =="
+    total = sum(_counter.values())
+    file.write("=== time ===\n")
     _print_profile(_counter, total, file)
-    print >>file, "== cumulative time =="
+    file.write("== cumulative time ==\n")
     _print_profile(_cum_counter, total, file)
+    if _outfile is not None:
+        file.close()
 
-
+def _show_profile_handler(signal, frame):
+    _show_profile()
 
 def main():
     parser = OptionParser(usage="%prog [options] script [script options]")
@@ -106,17 +112,27 @@ def main():
     global _outfile
     _outfile = options.outfile
 
+    if options.user1:
+        signal.signal(signal.SIGUSR1, _show_profile_handler)
+    if options.user2:
+        signal.signal(signal.SIGUSR1, _show_profile_handler)
+
     install(options.timer, options.interval)
 
     import atexit
     atexit.register(_show_profile)
 
     if (len(args) > 0):
+        progname = args[0]
         sys.argv[:] = args
         sys.path.insert(0, os.path.dirname(sys.argv[0]))
         import __main__
-        d = __main__.__dict__
-        execfile(sys.argv[0], d, d)
+        d = dict(__file__=progname,
+                 __name__='__main__',
+                 )
+        code = open(progname,'rb').read()
+        code = compile(code, progname, 'exec')
+        exec(code, d, d)
     else:
         parser.print_usage()
     return parser
